////////////////////////////////////////////////////////////////////////////////
//
//                  ObjectLab is sponsoring QALab
// 
// Based in London, we are world leaders in the design and development 
// of bespoke applications for the Securities Financing markets.
// 
// <a href="http://www.objectlab.co.uk/open">Click here to learn more</a>
//           ___  _     _           _   _          _
//          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
//         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
//         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
//          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
//                   |__/
//
//                   http://www.ObjectLab.co.uk
// ---------------------------------------------------------------------------
//
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.ant;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import net.objectlab.qalab.parser.BuildStatForChartParser;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * @author Benoit Xhenseval
 * @version $Revision: 189 $
 */
public class BuildStatChartTask extends Task {
    // ~ Static fields/initializers
    // ------------------------------------------------------------------------

    /** Default SAX parser. * */
//    protected static final String DEFAULT_PARSER_NAME = "org.apache.xerces.parsers.SAXParser";

    /** Default Chart width. * */
    private static final int DEFAULT_WIDTH = 950;

    /** Default Chart height. * */
    private static final int DEFAULT_HEIGHT = 600;

    // ~ Instance fields
    // ------------------------------------------------------------------------

    /** the base properties file. */
    private File inputFile = null;

    /** the merged properties file. */
    private File toDir = null;

    /** if true, logging output will be suppressed. */
    private boolean quiet = false;

    /** Chart width. * */
    private int width = DEFAULT_WIDTH;

    /** Chart height. * */
    private int height = DEFAULT_HEIGHT;

    /** moving Average for second line on Chart. * */
    private int movingAverage = 0;

    /** Summary only (1 chart only). * */
    private boolean summaryOnly = true;

    /** statistic type, defaulted to 'checkstyle'. * */
    private String type = "checkstyle";

    /** statistic type for the summary chart, defaulted to 'checkstyle'. * */
    private String summaryType = "checkstyle";

    /** Prefix for chart file names. * */
    private String filePrefix = "";
    
    /** X Axis Title */
    private String xAxisTitle = "Dates";
    
    /** Y Axis Title */
    private String yAxisTitle = "Violations";
    
    /** X Axis Title for Summary */
    private String xAxisSummaryTitle = "Dates";
    
    /** Y Axis Title for Summary */
    private String yAxisSummaryTitle = "Violations";
    

    // ~ Methods
    // ------------------------------------------------------------------------

    /**
     * Method invoked by the ant or maven framework to execute the action
     * associated with this task.
     */
    public final void execute() {
        // validate the provided parameters
        validate();

        // Display the files being processed
        if (!quiet) {
            log("inputFile='" + inputFile.getPath() + "', toDir='" + toDir.getPath() + "'");
            log("width='" + width + "' height='" + height + "' summaryOnly='" + summaryOnly + "'");
            log("type='" + type + "' summaryType='" + summaryType + "'");
        }

        generateCharts();
    }

    /**
     * Generate the charts by creating a SAX parser specialised in finding the
     * elements of given type and creating charts in a given directory.
     */
    private void generateCharts() {
        // define a sax stuff...
        BuildStatForChartParser myForChartParser = new BuildStatForChartParser(new AntTaskLogger(this));

        myForChartParser.setChartHeight(getHeight());
        myForChartParser.setChartWidth(getWidth());
        myForChartParser.setToDir(toDir.getAbsolutePath() + "/");
        myForChartParser.setMovingAverage(movingAverage);
        myForChartParser.setSummaryOnly(summaryOnly);
        myForChartParser.setSummaryStyle(summaryType);
        myForChartParser.setAcceptedStyle(type);
        myForChartParser.setQuiet(quiet);
        myForChartParser.setFilePrefix(getFilePrefix());
        myForChartParser.setXAxisSummaryTitle(xAxisSummaryTitle);
        myForChartParser.setYAxisSummaryTitle(yAxisSummaryTitle);
        myForChartParser.setXAxisTitle(xAxisTitle);
        myForChartParser.setYAxisTitle(yAxisTitle);

//        XMLReader parser = null;

        try {
            SAXParserFactory factory = SAXParserFactory.newInstance();
            SAXParser saxParser = factory.newSAXParser();

            if (!quiet) {
                log("Parsing " + inputFile);
            }

            saxParser.parse(new InputSource(new FileInputStream(inputFile)), myForChartParser);
//            parser = XMLReaderFactory.createXMLReader();
//            parser.setContentHandler(myForChartParser);
//            parser.setErrorHandler(myForChartParser);
//
//            if (!quiet) {
//                log("Parsing " + inputFile);
//            }
//
//            parser.parse(new InputSource(new FileInputStream(inputFile)));
        } catch (SAXException e) {
            log(e.toString());
        } catch (FileNotFoundException e) {
            log(e.toString());
        } catch (IOException e) {
            log(e.toString());
        } catch (ParserConfigurationException e) {
            log(e.toString());
        }
    }

    /**
     * Validates the parameters supplied by ant/maven.
     */
    private void validate() {
        if (inputFile == null) {
            throw new BuildException("inputFile is mandatory");
        }

        if (toDir == null) {
            throw new BuildException("toDir is mandatory");
        }

        if (!inputFile.canRead()) {
            final String message = "Unable to read from " + inputFile + ".";

            throw new BuildException(message);
        }

        if (toDir.exists() && !toDir.isDirectory()) {
            final String message = "toDir must be a directory (" + toDir + ")";

            throw new BuildException(message);
        }

        if (!toDir.exists()) {
            if (!quiet) {
                log("Creating directory: " + toDir.toString());
            }

            toDir.mkdir();
        }
    }

    /**
     * @param statisticsType
     *            the statistics type to take into account.
     */
    public final void setType(final String statisticsType) {
        this.type = statisticsType;
    }

    /**
     * Sets the base file (qalab.xml).
     * 
     * @param statisticsFile
     *            the qalab.xml
     */
    public final void setInputFile(final File statisticsFile) {
        this.inputFile = statisticsFile;
    }

    /**
     * Set the to directory where to output the charts.
     * 
     * @param targetDirectory
     *            the destination directory where the charts are written. The
     *            directory will be created if it does not exist.
     */
    public final void setToDir(final File targetDirectory) {
        this.toDir = targetDirectory;
    }

    /**
     * Sets the quiet mode.
     * 
     * @param beQuiet
     *            if true, no messages are displayed while generating charts.
     */
    public final void setQuiet(final boolean beQuiet) {
        this.quiet = beQuiet;
    }

    /**
     * @return the chart width in pixels.
     */
    public final int getWidth() {
        return width;
    }

    /**
     * set the chart width in pixels.
     * 
     * @param chartWidth
     *            number of pixels.
     */
    public final void setWidth(final int chartWidth) {
        this.width = chartWidth;
    }

    /**
     * @return the chart height in pixels.
     */
    public final int getHeight() {
        return height;
    }

    /**
     * set the chart height in pixels.
     * 
     * @param chartHeight
     *            number of pixels.
     */
    public final void setHeight(final int chartHeight) {
        this.height = chartHeight;
    }

    /**
     * @return number of points taken for form the moving average line.
     */
    public final int getMovingAverage() {
        return movingAverage;
    }

    /**
     * Set the number of points taken to form the moving average line, no moving
     * average line will be created if value <=0.
     * 
     * @param aMovingAverage
     *            no average if <=0
     */
    public final void setMovingAverage(final int aMovingAverage) {
        this.movingAverage = aMovingAverage;
    }

    /**
     * @return if true, only a summary chart will be generated (default).
     */
    public final boolean isSummaryOnly() {
        return summaryOnly;
    }

    /**
     * set the boolean summary only, if true, only a summary chart will be
     * generated.
     * 
     * @param onlySummary
     *            true will generate only 1 chart.
     */
    public final void setSummaryOnly(final boolean onlySummary) {
        this.summaryOnly = onlySummary;
    }

    /**
     * @return Returns the filePrefix.
     */
    public final String getFilePrefix() {
        return filePrefix;
    }

    /**
     * @param prefix
     *            The filePrefix to set.
     */
    public final void setFilePrefix(final String prefix) {
        this.filePrefix = prefix;
    }

    /**
     * @return Returns the summaryType.
     */
    public String getSummaryType() {
        return summaryType;
    }

    /**
     * @param theSummaryType
     *            The summaryType to set.
     */
    public void setSummaryType(final String theSummaryType) {
        this.summaryType = theSummaryType;
    }

    /**
     * @return Returns the xAxisSummaryTitle.
     */
    public String getXAxisSummaryTitle() {
        return xAxisSummaryTitle;
    }

    /**
     * @param axisSummaryTitle The xAxisSummaryTitle to set.
     */
    public void setXAxisSummaryTitle(String axisSummaryTitle) {
        xAxisSummaryTitle = axisSummaryTitle;
    }

    /**
     * @return Returns the xAxisTitle.
     */
    public String getXAxisTitle() {
        return xAxisTitle;
    }

    /**
     * @param axisTitle The xAxisTitle to set.
     */
    public void setXAxisTitle(String axisTitle) {
        xAxisTitle = axisTitle;
    }

    /**
     * @return Returns the yAxisSummaryTitle.
     */
    public String getYAxisSummaryTitle() {
        return yAxisSummaryTitle;
    }

    /**
     * @param axisSummaryTitle The yAxisSummaryTitle to set.
     */
    public void setYAxisSummaryTitle(String axisSummaryTitle) {
        yAxisSummaryTitle = axisSummaryTitle;
    }

    /**
     * @return Returns the yAxisTitle.
     */
    public String getYAxisTitle() {
        return yAxisTitle;
    }

    /**
     * @param axisTitle The yAxisTitle to set.
     */
    public void setYAxisTitle(String axisTitle) {
        yAxisTitle = axisTitle;
    }
}
/*
 *                   ObjectLab is sponsoring QALab
 * 
 * Based in London, we are world leaders in the design and development 
 * of bespoke applications for the securities financing markets.
 * 
 * <a href="http://www.objectlab.co.uk/open">Click here to learn more about us</a>
 *           ___  _     _           _   _          _
 *          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
 *         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
 *         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
 *          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
 *                   |__/
 *
 *                     www.ObjectLab.co.uk
 */
