////////////////////////////////////////////////////////////////////////////////
//
//                  ObjectLab is sponsoring QALab
// 
// Based in London, we are world leaders in the design and development 
// of bespoke applications for the Securities Financing markets.
// 
// <a href="http://www.objectlab.co.uk/open">Click here to learn more</a>
//           ___  _     _           _   _          _
//          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
//         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
//         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
//          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
//                   |__/
//
//                   http://www.ObjectLab.co.uk
// ---------------------------------------------------------------------------
//
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.parser;

import net.objectlab.qalab.util.QALabTags;
import net.objectlab.qalab.util.TaskLogger;
import net.objectlab.qalab.util.Util;

import org.jfree.chart.ChartColor;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartUtilities;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.DateAxis;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.xy.StandardXYItemRenderer;
import org.jfree.chart.renderer.xy.XYItemRenderer;
import org.jfree.chart.title.TextTitle;
import org.jfree.data.time.FixedMillisecond;
import org.jfree.data.time.MovingAverage;
import org.jfree.data.time.TimeSeries;
import org.jfree.data.time.TimeSeriesCollection;
import org.jfree.ui.Align;
import org.jfree.ui.HorizontalAlignment;
import org.jfree.ui.RectangleEdge;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;
import org.xml.sax.helpers.DefaultHandler;

import javax.swing.ImageIcon;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Font;
import java.awt.GradientPaint;
import java.awt.Image;
import java.awt.Paint;
import java.awt.Stroke;

import java.io.File;
import java.io.IOException;

import java.net.URL;

import java.text.ParseException;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

/**
 * This is the parser for generating the charts from qalab.xml.
 * 
 * Created by IntelliJ IDEA. User: xhensevalb Date: 09-Feb-2004 Time: 17:14:25
 * 
 * @version $Revision: 253 $
 */
public class BuildStatForChartParser extends DefaultHandler {
    // ~ Static fields/initializers
    // ------------------------------------------------------------------------

    private static final int NUM_HOURS_BEFORE_LAST_DATE = -28;

    private static final long ONE_DAY_IN_MS = 24L * 60L * 60L * 1000L;

    /** Default Summary Types */
    private static final String DEFAULT_SUMMARY_TYPES = "checkstyle,pmd,findbugs,simian";

    /** Default Types */
    private static final String DEFAULT_TYPES = "checkstyle,pmd,findbugs,simian,cobertura-branch,cobertura-line";

    /** footer font size. */
    private static final int DEFAULT_FONT_SIZE = 9;

    /** Chart parameters for fading the logo in. */
    private static final float ALPHA = 0.70f;

    /** Max Widths for chart. */
    private static final int MAX_WIDTH = 1000;

    /** Colours per type. */
    private static final Map COLOURS = new HashMap();

    /** Stroke per type. */
    private static final Map STROKES = new HashMap();

    static {
        COLOURS.put("findbugs", ChartColor.RED);
        COLOURS.put("pmd", new Color(0x55, 0x55, 0xFF));
        COLOURS.put("checkstyle", new Color(0x55, 0xFF, 0x55));
        COLOURS.put("pmd-cpd", new Color(0xFF, 0x55, 0xFF));
        COLOURS.put("simian", ChartColor.GRAY);
        COLOURS.put("cobertura-line", ChartColor.PINK);
        COLOURS.put("cobertura-branch", ChartColor.DARK_CYAN);

        STROKES.put("checkstyle", new BasicStroke(2.0f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND, 1.0f, new float[] { 2.0f,
                6.0f }, 0.0f));
        STROKES.put("findbugs", new BasicStroke(2.0f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND, 1.0f, new float[] { 2.0f,
                3.0f }, 1.0f));
        STROKES.put("cobertura-branch", new BasicStroke(2.0f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
        STROKES.put("cobertura-line", new BasicStroke(2.0f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
        STROKES.put("simian", new BasicStroke(2.0f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
        STROKES.put("pmd-cpd", new BasicStroke(2.0f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
        STROKES.put("pmd", new BasicStroke(2.0f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
    }

    // ~ Instance fields
    // ------------------------------------------------------------------------

    /** the logger to use. */
    private TaskLogger parentTask;

    /** true if the current element is a summary one. */
    private boolean currentElementisSummary = false;

    /** output directory. */
    private String toDir = "";

    /** chart width in pixels. */
    private int chartWidth;

    /** chart height. */
    private int chartHeight;

    /** moving average for second line, none if <=0. */
    private int movingAverage = 0;

    /** if true, generate only the summary chart. */
    private boolean summaryOnly = true;

    /** current element name. */
    private String currentName;

    /** true if current statistics relates to file. */
    private boolean fileStat = false;

    /** series of dates per types. */
    private Map dates = new HashMap();

    /** series of statistics per types. */
    private Map errors = new HashMap();

    /** the accepted styles as a List of Strings. */
    private List types = Collections.EMPTY_LIST;

    /** the accepted styles as a List of Strings. */
    private List summaryTypes = Collections.EMPTY_LIST;

    /** The logo to put in the bottom left corner of charts. */
    private Image logo;

    /** if true, no debug output. */
    private boolean quiet = true;

    /** file prefix for the chart names. */
    private String filePrefix = "";

    /** X Axis Title */
    private String xAxisTitle = "Dates";

    /** Y Axis Title */
    private String yAxisTitle = "Violations";

    /** X Axis Title for Summary */
    private String xAxisSummaryTitle = "Dates";

    /** Y Axis Title for Summary */
    private String yAxisSummaryTitle = "Violations";

    // ~ Constructors
    // ------------------------------------------------------------------------

    /**
     * constructor, accepts the logger.
     * 
     * @param logger
     *            the looger for this task, will vary if ant/maven/other.
     */
    public BuildStatForChartParser(final TaskLogger logger) {
        parentTask = logger;
        setAcceptedStyle(DEFAULT_TYPES);
        setSummaryStyle(DEFAULT_SUMMARY_TYPES);
    }

    // ~ Methods
    // ------------------------------------------------------------------------

    /**
     * set the accepted styles for charts, each type will be a line/series on
     * the chart. Accepted as a comma separated string, eg checkstyle,pmd for
     * both PMD and Checkstyle.
     * 
     * @param acceptedStyleStr
     *            a comma separated string with styles.
     */
    public final void setAcceptedStyle(final String acceptedStyleStr) {
        types = Util.listify(acceptedStyleStr, ",");
    }

    /**
     * set the accepted styles for SUMMARY charts, each type will be a
     * line/series on the chart. Accepted as a comma separated string, eg
     * checkstyle,pmd for both PMD and Checkstyle.
     * 
     * @param acceptedStyleStr
     *            a comma separated string with styles.
     */
    public final void setSummaryStyle(final String acceptedStyleStr) {
        summaryTypes = Util.listify(acceptedStyleStr, ",");
        if (!quiet) {
            parentTask.log("Summary Styles: " + summaryTypes);
        }
    }

    //
    // ContentHandler methods
    //

    /**
     * Start element, called when each new tag is encountered.
     * 
     * @param ignoreUri
     *            ignore, this is due to sax interface.
     * @param local
     *            local name of the tag.
     * @param ignoreRaw
     *            ignore, this is due to sax interface.
     * @param attrs
     *            the element attributes.
     * @throws SAXException
     *             any SAX parser exception.
     */
    public final void startElement(final String ignoreNamespaceURI, // NOPMD
            final String localname, final String qualifiedname, final Attributes attrs) throws SAXException {
        String local = localname;

        if ("".equals(local)) {
            local = qualifiedname;
        }

        if (!currentElementisSummary && QALabTags.SUMMARY_TAG.equals(local)) {
            currentElementisSummary = true;
            currentName = QALabTags.SUMMARY_TAG;
        }

        if (!currentElementisSummary && !fileStat && QALabTags.FILE_TAG.equals(local)) {
            fileStat = true;
            currentName = getFileName(attrs);
            dates.clear();
            errors.clear();
        }

        if (currentElementisSummary) {
            processSummaryResult(local, attrs);
        } else if (!isSummaryOnly() && fileStat) {
            processFileResult(local, attrs);
        }
    }

    /**
     * Process a file result.
     * 
     * @param local
     *            name of element.
     * @param attrs
     *            attributes of element.
     */
    private void processFileResult(final String local, final Attributes attrs) {
        if (!QALabTags.RESULT_TAG.equals(local)) {
            return;
        }

        processResult(attrs);
    }

    /**
     * Helper method that add a non-null value to an array in a map for the
     * given type. The map contains pairs string-array.
     * 
     * @param map
     *            where the item will be stored if val!=null
     * @param type
     *            the key in the map
     * @param val
     *            the value (to be added to an array).
     */
    private void add(final Map map, final String type, final Object val) {
        if (val == null) {
            return;
        }

        List list = (List) map.get(type);

        if (list == null) {
            list = new ArrayList();
            map.put(type, list);
        }

        list.add(val);
    }

    /**
     * Extract the file name (id) from an element.
     * 
     * @param attrs
     *            XML attributes
     * @return null if id attribute is not found.
     */
    private String getFileName(final Attributes attrs) {
        String fileName = null;
        final int attrCount = attrs.getLength();

        for (int i = 0; i < attrCount; i++) {
            final String attribute = attrs.getQName(i);

            if (QALabTags.ID_ATTRIBUTE.equals(attribute)) {
                fileName = attrs.getValue(i).replace('/', '_');

                break;
            }
        }

        return fileName;
    }

    /**
     * Process a summary result.
     * 
     * @param local
     *            name of element.
     * @param attrs
     *            attributes of element.
     */
    private void processSummaryResult(final String local, final Attributes attrs) {
        if (!QALabTags.SUMMARY_RESULT_TAG.equals(local)) {
            return;
        }

        processResult(attrs);
    }

    /**
     * Both summary and file results are actually quite similar with the
     * attributes 'type', 'date' and 'statvalue' being extracted for charting.
     * 
     * @param attrs
     *            list of attributes.
     */
    private void processResult(final Attributes attrs) {
        final int attrCount = attrs.getLength();
        Date date = null;
        boolean accepted = false;
        Integer error = null;
        String type = null;

        // this loop goes through all attributes to extract
        // the attributes, there is no check that we get a full
        // set.
        for (int i = 0; i < attrCount; i++) {
            final String attribute = attrs.getQName(i);

            final String value = attrs.getValue(i);
            if (QALabTags.TYPE_ATTRIBUTE.equals(attribute)) {
                type = value;
                if (currentElementisSummary) {
                    if (!quiet) {
                        parentTask.log("Check that the summary " + value + " is accepted in " + summaryTypes);
                    }
                    accepted = summaryTypes.contains(value);
                } else {
                    accepted = types.contains(value);
                }
            } else if (QALabTags.STATVALUE_ATTRIBUTE.equals(attribute)) {
                error = Integer.valueOf(value);
            } else if (QALabTags.DATE_ATTRIBUTE.equals(attribute)) {
                try {
                    if (value != null && value.length() > QALabTags.DATE_ONLY_SIZE) {
                        date = QALabTags.DEFAULT_DATETIME_FORMAT.parse(value);
                    } else if (value != null && value.length() == QALabTags.DATE_ONLY_SIZE) {
                        date = QALabTags.DEFAULT_DATE_FORMAT.parse(value);
                    } else {
                        throw new IllegalArgumentException("OUCH -> date size = " + (value != null ? value.length() : 0) + " ["
                                + value + "]");
                    }
                } catch (ParseException e) {
                    parentTask.log(e.getMessage());
                }
            }
        }

        // we add only the accepted types.
        if (accepted) {
            add(dates, type, date);
            add(errors, type, error);
        }
    }

    //
    // ErrorHandler methods
    //

    /**
     * Warning.
     * 
     * @param ex
     *            the SAX Parser Exception.
     * @throws SAXException
     *             any SAX Parser Exception.
     */
    public final void warning(final SAXParseException ex) throws SAXException {
        printError("Warning", ex);
    }

    /**
     * Error.
     * 
     * @param ex
     *            the SAX Parser Exception.
     * @throws SAXException
     *             any SAX Parser Exception.
     */
    public final void error(final SAXParseException ex) throws SAXException {
        printError("Error", ex);
    }

    /**
     * Fatal error.
     * 
     * @param ex
     *            the SAX Parser Exception.
     * @throws SAXException
     *             any SAX Parser Exception.
     */
    public final void fatalError(final SAXParseException ex) throws SAXException {
        printError("Fatal Error", ex);
    }

    /**
     * Common handling of SAX errors & warnings, log it to the given logger.
     * 
     * @param errorType
     *            warning/error/fatal
     * @param ex
     *            the SAX exception
     */
    private void printError(final String errorType, final SAXParseException ex) {
        final StringBuffer buf = new StringBuffer();

        buf.append("[").append(errorType).append("] ");

        if (ex == null) {
            buf.append("!!!");
        }

        if (ex != null) {
            String systemId = ex.getSystemId();

            if (systemId != null) {
                final int index = systemId.lastIndexOf('/');

                if (index != -1) {
                    systemId = systemId.substring(index + 1);
                }

                buf.append(systemId);
            }

            buf.append(':');
            buf.append(ex.getLineNumber());
            buf.append(':');
            buf.append(ex.getColumnNumber());
            buf.append(": ");
            buf.append(ex.getMessage());
        }

        parentTask.log(buf.toString());
    }

    /**
     * Called when a closing element tag is encountered, it generates the chart
     * each time it moves from a file or summary.
     * 
     * @param ignoreUri
     *            ignore, this is due to sax interface.
     * @param localName
     *            local name of the tag.
     * @param ignoreQName
     *            ignore, this is due to sax interface.
     * @throws SAXException
     *             any SAX exceptions.
     */
    public final void endElement(final String ignoreNamespaceURI, // NOPMD
            final String localName, final String qualifiedname) // NOPMD
            throws SAXException {
        String local = localName;
        if ("".equals(local)) {
            local = qualifiedname;
        }
        if (currentElementisSummary && QALabTags.SUMMARY_TAG.equals(local)) {
            currentElementisSummary = false;

            if (!quiet) {
                parentTask.log("Summary Found Dates:" + dates + " / errors " + errors);
            }

            chart("summary", dates, errors, true, true);
        } else if (!isSummaryOnly() && fileStat && QALabTags.FILE_TAG.equals(local)) {
            fileStat = false;

            if (!quiet) {
                parentTask.log("Found " + currentName + " Dates:" + dates + " / errors " + errors);
            }

            chart(currentName, dates, errors, false, false);
        }
    }

    /**
     * Generates the chart using jFreeChart, each type will generate a series.  The chart
     * will check the LATEST date on record across all types, if the last day of a given type
     * is AT LEAST 28h before the latest date and there are NO records afterwards, we shall
     * assume that the statistics have fallen to 0 and draw a line down to 0 for the day after.
     * 
     * @param name
     *            name of the chart either summary or the file name.
     * @param theDates
     *            the map of dates available per type.
     * @param theErrors
     *            the map of error counts available per type.
     * @param withAverage
     *            if true, generate a second series showing. moving average.
     */
    private void chart(final String name, final Map theDates, final Map theErrors, final boolean withAverage,
            final boolean summaryChart) {
        try {
            if (theDates.size() == 0) {
                return;
            }

            List availableTypes = new ArrayList();
            final TimeSeriesCollection series = new TimeSeriesCollection();
            buildTimeSeries(theDates, theErrors, withAverage, availableTypes, series);

            StringBuffer existingTypes = new StringBuffer();
            for (Iterator it = availableTypes.iterator(); it.hasNext();) {
                existingTypes.append(it.next()).append(" ");
            }

            String title = existingTypes.toString() + " Stats " + name;

            String yTitle = getYAxisTitle();
            String xTitle = getXAxisTitle();
            if (summaryChart) {
                yTitle = getYAxisSummaryTitle();
                xTitle = getXAxisSummaryTitle();
            }
            final JFreeChart chart = ChartFactory.createTimeSeriesChart(title, xTitle, yTitle, series, true, false, false);

            final TextTitle copyright = new TextTitle("QALab 2004+,ObjectLab.co.uk Generated "
                    + QALabTags.DEFAULT_DATETIME_FORMAT.format(new Date()), new Font("SansSerif", Font.PLAIN, DEFAULT_FONT_SIZE));

            copyright.setPosition(RectangleEdge.BOTTOM);
            copyright.setHorizontalAlignment(HorizontalAlignment.RIGHT);
            chart.addSubtitle(copyright);

            chart.setBackgroundImage(getLogo());
            chart.setBackgroundImageAlpha(ALPHA);
            chart.setBackgroundImageAlignment(Align.BOTTOM_LEFT);
            chart.setBackgroundPaint(new GradientPaint(0, 0, Color.white, 0, MAX_WIDTH, Color.blue));

            final XYPlot xyPlot = chart.getXYPlot();
            final XYItemRenderer renderer = xyPlot.getRenderer();
            if (!withAverage && renderer instanceof StandardXYItemRenderer) {
                final StandardXYItemRenderer rr = (StandardXYItemRenderer) renderer;

                rr.setPlotImages(true);
                rr.setShapesFilled(Boolean.TRUE);
            }

            int index = 0;
            for (Iterator it = availableTypes.iterator(); it.hasNext(); index++) {
                final String type = (String) it.next();

                renderer.setSeriesPaint(index, (Paint) COLOURS.get(type));
                Stroke stroke = (Stroke) STROKES.get(type);
                if (stroke != null) {
                    renderer.setSeriesStroke(index, stroke);
                }
            }

            final DateAxis axis = (DateAxis) xyPlot.getDomainAxis();

            axis.setVerticalTickLabels(true);

            final File file2 = new File(getToDir() + getFilePrefix() + name + ".png");

            ChartUtilities.saveChartAsPNG(file2, chart, getChartWidth(), getChartHeight());
        } catch (IOException e) {
            parentTask.log(e.toString());
        }
    }

    private void buildTimeSeries(final Map theDates, final Map theErrors, final boolean withAverage, 
            final List availableTypes, final TimeSeriesCollection series) {
        final Iterator typeIter = theDates.entrySet().iterator();
        final Date max = findMaxDate(theDates);
        final Calendar cal = Calendar.getInstance();
        cal.setTime(max);
        cal.add(Calendar.HOUR_OF_DAY, NUM_HOURS_BEFORE_LAST_DATE); // no stats over the last 28h
        final Date zeroDeadline = cal.getTime(); // no stats over the last 28h

        while (typeIter.hasNext()) {
            final Map.Entry pairTypeDates = (Map.Entry) typeIter.next();
            final String type = (String) pairTypeDates.getKey();
            availableTypes.add(type);
            final TimeSeries ts = new TimeSeries(type, "bla", "bli", FixedMillisecond.class);

            final List typeDates = (List) pairTypeDates.getValue();
            final List typeErrors = (List) theErrors.get(type);

            if ((typeDates != null) && (typeErrors != null)) {
                addDataToTimeSeries(zeroDeadline, ts, typeDates, typeErrors);
            }

            series.addSeries(ts);

            if (withAverage && (getMovingAverage() > 0)) {
                series.addSeries(MovingAverage.createPointMovingAverage(ts, type + " " + getMovingAverage()
                        + "-run Moving Average", getMovingAverage()));
            }
        }
    }

    private void addDataToTimeSeries(final Date zeroDeadline, final TimeSeries ts, final List typeDates, final List typeErrors) {
        final Iterator dateIter = typeDates.iterator();
        final Iterator errorsIter = typeErrors.iterator();

        Date lastDateForThisType = null;
        while (dateIter.hasNext() && errorsIter.hasNext()) {
            lastDateForThisType = (Date) dateIter.next();
            final Integer count = (Integer) errorsIter.next();

            ts.addOrUpdate(new FixedMillisecond(lastDateForThisType), count);
        }

        // if no statistics for 36h before the LAST Date, assume it fell to 0.
        if (lastDateForThisType != null && zeroDeadline != null && zeroDeadline.after(lastDateForThisType)) {
            ts.addOrUpdate(new FixedMillisecond(lastDateForThisType.getTime() + ONE_DAY_IN_MS), 0);
        }
    }

    private Date findMaxDate(Map theDates) {
        Date maxDate = null;
        final Iterator typeIter = theDates.entrySet().iterator();
        while (typeIter.hasNext()) {
            final Map.Entry pairTypeDates = (Map.Entry) typeIter.next();
            final List typeDates = (List) pairTypeDates.getValue();

            if (typeDates != null) {
                for (Iterator it = typeDates.iterator(); it.hasNext();) {
                    Date date = (Date) it.next();
                    if (maxDate != null) {
                        maxDate = (maxDate.before(date) ? date : maxDate);
                    } else {
                        maxDate = date;
                    }
                }
            }
        }
        return maxDate;
    }

    /**
     * @return Returns the yAxisSummaryTitle.
     */
    public String getYAxisSummaryTitle() {
        return yAxisSummaryTitle;
    }

    /**
     * @param axisSummaryTitle
     *            The yAxisSummaryTitle to set.
     */
    public void setYAxisSummaryTitle(String axisSummaryTitle) {
        yAxisSummaryTitle = axisSummaryTitle;
    }

    /**
     * Include a logo for the bottom left corner.
     * 
     * @return Image, the logo to include.
     */
    private Image getLogo() {
        if (logo == null) {
            final URL url = BuildStatForChartParser.class.getResource("/net/objectlab/qalab/objectlab.gif");

            // use ImageIcon because it waits for the image to load...
            final ImageIcon temp = new ImageIcon(url);

            logo = temp.getImage();
        }

        return logo;
    }

    /**
     * @return chart width in pixels.
     */
    public final int getChartWidth() {
        return chartWidth;
    }

    /**
     * @param width
     *            in pixels.
     */
    public final void setChartWidth(final int width) {
        this.chartWidth = width;
    }

    /**
     * @return chart height in pixels.
     */
    public final int getChartHeight() {
        return chartHeight;
    }

    /**
     * @param height
     *            in pixels.
     */
    public final void setChartHeight(final int height) {
        this.chartHeight = height;
    }

    /**
     * @return output directory.
     */
    public final String getToDir() {
        return toDir;
    }

    /**
     * @param outputDirectory
     *            output directory.
     */
    public final void setToDir(final String outputDirectory) {
        this.toDir = outputDirectory;
    }

    /**
     * @return number of point to take into account for moving average.
     */
    public final int getMovingAverage() {
        return movingAverage;
    }

    /**
     * @param average
     *            number of points to take into account in moving average, no
     *            moving average if <= 0.
     */
    public final void setMovingAverage(final int average) {
        this.movingAverage = average;
    }

    /**
     * @return Returns the xAxisSummaryTitle.
     */
    public String getXAxisSummaryTitle() {
        return xAxisSummaryTitle;
    }

    /**
     * @param axisSummaryTitle
     *            The xAxisSummaryTitle to set.
     */
    public void setXAxisSummaryTitle(String axisSummaryTitle) {
        xAxisSummaryTitle = axisSummaryTitle;
    }

    /**
     * @return true if only summary chart required.
     */
    public final boolean isSummaryOnly() {
        return summaryOnly;
    }

    /**
     * @param summary
     *            true if we require only summary chart.
     */
    public final void setSummaryOnly(final boolean summary) {
        this.summaryOnly = summary;
    }

    /**
     * @return true if no debug log required.
     */
    public final boolean isQuiet() {
        return quiet;
    }

    /**
     * @param noLog
     *            true if no debug log required.
     */
    public final void setQuiet(final boolean noLog) {
        this.quiet = noLog;
    }

    /**
     * @return Returns the filePrefix.
     */
    public String getFilePrefix() {
        if (filePrefix == null) {
            return "";
        } else {
            return filePrefix;
        }
    }

    /**
     * @param filePrefix
     *            The filePrefix to set.
     */
    public void setFilePrefix(String filePrefix) {
        this.filePrefix = filePrefix;
    }

    /**
     * @return Returns the xAxisTitle.
     */
    public String getXAxisTitle() {
        return xAxisTitle;
    }

    /**
     * @param axisTitle
     *            The xAxisTitle to set.
     */
    public void setXAxisTitle(String axisTitle) {
        xAxisTitle = axisTitle;
    }

    /**
     * @return Returns the yAxisTitle.
     */
    public String getYAxisTitle() {
        return yAxisTitle;
    }

    /**
     * @param axisTitle
     *            The yAxisTitle to set.
     */
    public void setYAxisTitle(String axisTitle) {
        yAxisTitle = axisTitle;
    }
}
/*
 *                   ObjectLab is sponsoring QALab
 * 
 * Based in London, we are world leaders in the design and development 
 * of bespoke applications for the securities financing markets.
 * 
 * <a href="http://www.objectlab.co.uk/open">Click here to learn more about us</a>
 *           ___  _     _           _   _          _
 *          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
 *         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
 *         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
 *          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
 *                   |__/
 *
 *                     www.ObjectLab.co.uk
 */
