////////////////////////////////////////////////////////////////////////////////
//
//                  ObjectLab is sponsoring QALab
// 
// Based in London, we are world leaders in the design and development 
// of bespoke applications for the Securities Financing markets.
// 
// <a href="http://www.objectlab.co.uk/open">Click here to learn more</a>
//           ___  _     _           _   _          _
//          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
//         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
//         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
//          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
//                   |__/
//
//                   http://www.ObjectLab.co.uk
// ---------------------------------------------------------------------------
//
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.parser;

import net.objectlab.qalab.util.FilenameUtil;
import net.objectlab.qalab.util.Util;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

/**
 * This abstract class defines most common code between the handling of
 * Checkstyle and PMD XML.
 *
 * @author Benoit Xhenseval
 * @version $Revision: 187 $
 */
public abstract class CheckstyleOrPMDBaseMerge extends BaseStatMerge {
    /**
     * At the start of a new element, capture the filename and if the element
     * is a result one, create a SingleStat to store for the given type.
     * @param ignoreNamespaceURI ignore (present for interface implementation).
     * @param localname name of the current element.
     * @param qualifiedname element name.
     * @param attrs the XML attribute of the current element.
     * @throws SAXException any SAX issue
     */
    public final void startElement(final String ignoreNamespaceURI, // NOPMD
        final String localname, final String qualifiedname,
        final Attributes attrs)
        throws SAXException {
        String local = localname;

        if ("".equals(local)) {
            local = qualifiedname;
        }

//        if (!isQuiet()) {
//            getTaskLogger().log("Start :" + local);
//        }

        if (getFileTag().equals(local)) {
            // this is the start of a new file.
            resetFileStatistics();
            incrementFileCount(1);
            setFileName(attrs);
        } if (getViolationTag().equals(local)) {
            // this is the start of a new error
            addFileStatistics(1);
        }
    }

    /**
     * At the end of an element, check if it is a file one and add the
     * results found.
     * @param ignoreNamespaceURI ignore (present for interface implementation).
     * @param ignoreSimplename ignore (present for interface implementation).
     * @param qualifiedname the name of the element.
     * @throws SAXException any SAX issue
     */
    public final void endElement(final String ignoreNamespaceURI, // NOPMD
        final String ignoreSimplename, final String qualifiedname) // NOPMD
        throws SAXException {
//        if (!isQuiet()) {
//            getTaskLogger().log("End :" + qualifiedname);
//        }

        if (getFileTag().equals(qualifiedname)) {
            addNewResults();
        }
    }

    /**
     * @return the tag for "file"
     */
    protected abstract String getFileTag();

    /**
     * @return the attribute name for fileName
     */
    protected abstract String getFileNameAttribute();

    /**
     * @return tag for a violation/error
     */
    protected abstract String getViolationTag();

    /**
     * set the file name from the attributes from Checkstyle/Findbugs XML.
     * @param att xml attributes
     */
    protected void setFileName(final Attributes att) {
        String fileName = Util.getAttributeValue(att, getFileNameAttribute(),
                isQuiet(), getTaskLogger());

        if (!isQuiet()) {
            getTaskLogger().log("File:" + fileName);
        }

        fileName = FilenameUtil.trimFilename(fileName, getSrcDir());

        if (!isQuiet()) {
            getTaskLogger().log("setCurrentFileName FILE [" + fileName
                + "] srcDir [" + getSrcDir() + "]");
        }

        setCurrentFile(fileName);
    }
}
/*
 *                   ObjectLab is sponsoring QALab
 * 
 * Based in London, we are world leaders in the design and development 
 * of bespoke applications for the securities financing markets.
 * 
 * <a href="http://www.objectlab.co.uk/open">Click here to learn more about us</a>
 *           ___  _     _           _   _          _
 *          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
 *         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
 *         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
 *          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
 *                   |__/
 *
 *                     www.ObjectLab.co.uk
 */
