////////////////////////////////////////////////////////////////////////////////
//
//                  ObjectLab is sponsoring QALab
// 
// Based in London, we are world leaders in the design and development 
// of bespoke applications for the Securities Financing markets.
// 
// <a href="http://www.objectlab.co.uk/open">Click here to learn more</a>
//           ___  _     _           _   _          _
//          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
//         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
//         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
//          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
//                   |__/
//
//                   http://www.ObjectLab.co.uk
// ---------------------------------------------------------------------------
//
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.parser;

import net.objectlab.qalab.util.Util;

import org.xml.sax.Attributes;

/**
 * This class is able to read the XDOC output from FindBugs and integrate the
 * violation results into our qalab.xml format.
 * 
 * @see <a href="http://findbugs.sourceforge.net/">FindBugs at SourceForge</a>
 * @author Benoit Xhenseval
 * @version $Revision: 187 $
 */
public class FindBugsStatMerge extends CheckstyleOrPMDBaseMerge {
    // ~ Methods
    // ------------------------------------------------------------------------

    /**
     * @return "file"
     */
    protected final String getFileTag() {
        return "file";
    }

    /**
     * @return classname
     */
    protected final String getFileNameAttribute() {
        return "classname";
    }

    /**
     * @return BugInstance
     */
    protected final String getViolationTag() {
        return "BugInstance";
    }

    /**
     * @return findbugs
     */
    public final String getType() {
        return "findbugs";
    }

    /**
     * Given the different ways that files can be stored on file system, this
     * method will remove anything part of the path up to the 'srcDir' given, it
     * should only retain the package name in java. For instance, for Findbugs
     * classname="net.objectlab.X" will be stored in the compiled stats as:
     * net/objectlab/A.java
     * 
     * @param att
     *            the XML attribute
     */
    protected final void setFileName(final Attributes att) {
        String fileName = Util.getAttributeValue(att, getFileNameAttribute(),
                isQuiet(), getTaskLogger());

        fileName = fileName.replace('.', '/');

        final int embeddedClass = fileName.indexOf("$");

        if (embeddedClass > 0) {
            fileName = fileName.substring(0, embeddedClass);
        }

        fileName += ".java";

        if (!isQuiet()) {
            getTaskLogger().log("setCurrentFileName FILE [" + fileName + "]");
        }

        setCurrentFile(fileName);
    }
}
/*
 *                   ObjectLab is sponsoring QALab
 * 
 * Based in London, we are world leaders in the design and development 
 * of bespoke applications for the securities financing markets.
 * 
 * <a href="http://www.objectlab.co.uk/open">Click here to learn more about us</a>
 *           ___  _     _           _   _          _
 *          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
 *         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
 *         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
 *          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
 *                   |__/
 *
 *                     www.ObjectLab.co.uk
 */
