////////////////////////////////////////////////////////////////////////////////
//
//                  ObjectLab is sponsoring QALab
// 
// Based in London, we are world leaders in the design and development 
// of bespoke applications for the Securities Financing markets.
// 
// <a href="http://www.objectlab.co.uk/open">Click here to learn more</a>
//           ___  _     _           _   _          _
//          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
//         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
//         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
//          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
//                   |__/
//
//                   http://www.ObjectLab.co.uk
// ---------------------------------------------------------------------------
//
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.parser;

import net.objectlab.qalab.util.Util;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

/**
 * This class is able to read the XML output from PMD CPD (Copy Paste Detector)
 * and integrate the violation results into our "qalab" xml format.
 *
 * @author Benoit Xhenseval
 * @version $Revision: 153 $
 */
public class PMDCPDStatMerge extends BaseStatMerge {
    // ~ Static fields/initializers
    // ------------------------------------------------------------------------

    /**
     * summary tag.
     */
    private static final String BUGINSTANCE_TAG = "duplication";

    // ~ Methods
    // ------------------------------------------------------------------------

    /**
     * @return simian
     */
    public final String getType() {
        return "pmd-cpd";
    }

    /**
     * At the start of a new element, capture the filename and if the element
     * is a result one, create a SingleStat to store for the given type.
     * @param ignoreNamespaceURI ignore (present for interface implementation).
     * @param localname name of the current element.
     * @param qualifiedname element name.
     * @param attrs the XML attribute of the current element.
     * @throws SAXException any SAX issue
     */
    public final void startElement(final String ignoreNamespaceURI, // NOPMD
        final String localname, final String qualifiedname,
        final Attributes attrs)
        throws SAXException {
        String local = localname;

        if ("".equals(local)) {
            local = qualifiedname;
        }

        if (BUGINSTANCE_TAG.equals(local)) {
            final String dupLines = Util.getAttributeValue(attrs,
                    "lines", isQuiet(), getTaskLogger());
//            final String dupFileCount = 2; 
//            Util.getAttributeValue(attrs,
//                    "duplicateFileCount", isQuiet(), getTaskLogger());

            if (!isQuiet()) {
                getTaskLogger().log("dupLineCount=" + dupLines);
//                    + " dupFileCount=" + dupFileCount);
            }

            addTotalStatistics(Integer.parseInt(dupLines));
            incrementFileCount(2);
            addNewResults();
        }
    }
}
/*
 *                   ObjectLab is sponsoring QALab
 * 
 * Based in London, we are world leaders in the design and development 
 * of bespoke applications for the securities financing markets.
 * 
 * <a href="http://www.objectlab.co.uk/open">Click here to learn more about us</a>
 *           ___  _     _           _   _          _
 *          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
 *         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
 *         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
 *          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
 *                   |__/
 *
 *                     www.ObjectLab.co.uk
 */
