////////////////////////////////////////////////////////////////////////////////
//
//                  ObjectLab is sponsoring QALab
// 
// Based in London, we are world leaders in the design and development 
// of bespoke applications for the Securities Financing markets.
// 
// <a href="http://www.objectlab.co.uk/open">Click here to learn more</a>
//           ___  _     _           _   _          _
//          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
//         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
//         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
//          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
//                   |__/
//
//                   http://www.ObjectLab.co.uk
// ---------------------------------------------------------------------------
//
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.util;


/**
 * Utility class for file name manipulations.
 * 
 * @author Dave Sag
 */
public final class FilenameUtil {
    /**
     * default constructor.
     */
    private FilenameUtil() {
    }

    /**
     * Trims the supplied filename by forcing it to be a unix path and choping
     * off everything below the src directory.
     * 
     * @param aFilename
     *            The original absolute filename.
     * @param aSrcDir
     *            the path to the src folder.
     * @return a trimmed file name suitable for display.
     */
    public static String trimFilename(final String aFilename, final String aSrcDir) {
        // force path separators to be unix for display.
        String fn = aFilename.replace('\\', '/');
        if (aSrcDir != null && aSrcDir.length() > 0) {
            final String sdir = aSrcDir.replace('\\', '/');

            final int startCutPoint = fn.indexOf(sdir);

            if (startCutPoint >= 0) {
                int cutpoint = startCutPoint + sdir.length();

                if (!sdir.endsWith("/")) {
                    // must skip the first "/" from the file name.
                    cutpoint++;
                }

                fn = fn.substring(cutpoint);
            }
        }

        return fn;
    }
}
/*
 *                   ObjectLab is sponsoring QALab
 * 
 * Based in London, we are world leaders in the design and development 
 * of bespoke applications for the securities financing markets.
 * 
 * <a href="http://www.objectlab.co.uk/open">Click here to learn more about us</a>
 *           ___  _     _           _   _          _
 *          / _ \| |__ (_) ___  ___| |_| |    __ _| |__
 *         | | | | '_ \| |/ _ \/ __| __| |   / _` | '_ \
 *         | |_| | |_) | |  __/ (__| |_| |__| (_| | |_) |
 *          \___/|_.__// |\___|\___|\__|_____\__,_|_.__/
 *                   |__/
 *
 *                     www.ObjectLab.co.uk
 */
